nsi.granulate.GranularUtils

Package nsi :: Package granulate :: Module GranularUtils |
[hide private]
[frames] | no frames]

# Source Code for Module nsi.granulate.GranularUtils

     1  ##############################################################################
     2  #
     3  # Copyright (c) 2007 ISrg (NSI, CEFETCAMPOS, BRAZIL) and Contributors.
     4  #                                                         All Rights Reserved.
     5  #
     6  # WARNING: This program as such is intended to be used by professional
     7  # programmers who take the whole responsability of assessing all potential
     8  # consequences resulting from its eventual inadequacies and bugs
     9  # End users who are looking for a ready-to-use solution with commercial
    10  # garantees and support are strongly adviced to contract a Free Software
    11  # Service Company
    12  #
    13  # This program is Free Software; you can redistribute it and/or
    14  # modify it under the terms of the GNU General Public License
    15  # as published by the Free Software Foundation; either version 2
    16  # of the License, or (at your option) any later version.
    17  #
    18  # This program is distributed in the hope that it will be useful,
    19  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    20  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    21  # GNU General Public License for more details.
    22  #
    23  # You should have received a copy of the GNU General Public License
    24  # along with this program; if not, write to the Free Software
    25  # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    26  #
    27  ##############################################################################
    28
    29 -class Grain:
    30      """
    31          This Class is used as reference to manipulate Grains
    32      """
    33 -    def __init__(self, id=None, caption=None, content=None):
    34          """
    35              The default attributes represent the metadata from Grain.
    36          """
    37          self.id = id
    38          self.caption = caption
    39          self.content = content
    40
    41 -    def __call__(self):
    42          """
    43              Should be used getContent instead of __call___
    44              For this object, call is useless.
    45          """
    46          return self.getContent()
    47
    48 -    def getId(self):
    49          return self.id
    50
    51 -    def setId(self,id=None):
    52          self.id = id
    53
    54 -    def getCaption(self):
    55          return self.caption
    56
    57 -    def setCaption(self,caption=None):
    58          self.caption = caption
    59
    60 -    def getContent(self):
    61          """
    62              Content is usually a StringIO.
    63          """
    64          return self.content
    65
    66 -    def setContent(self,content=None):
    67          """
    68              Content should receive only a StringIO
    69          """
    70          self.content = content
    71